@@ -24,6 +24,7 @@
 #include <ClassListWidget.h>
 
 #include <KCupsRequest.h>
+#include <KLocalizedString>
 
 #include <QPainter>
 
@@ -51,11 +52,10 @@ PageChoosePrinters::PageChoosePrinters(const QVariantHash &args, QWidget *parent
                                              KIconLoader::SizeLarge, // a not so huge icon
                                              KIconLoader::DefaultState);
     // the emblem icon to size 32
-    int overlaySize = KIconLoader::SizeLarge;
-    QPoint startPoint;
+    const int overlaySize = KIconLoader::SizeLarge;
     // bottom right corner
-    startPoint = QPoint(KIconLoader::SizeEnormous - overlaySize - 2,
-                        KIconLoader::SizeEnormous - overlaySize - 2);
+    const QPoint startPoint = QPoint(KIconLoader::SizeEnormous - overlaySize - 2,
+                                     KIconLoader::SizeEnormous - overlaySize - 2);
     painter.drawPixmap(startPoint, pixmap);
     ui->printerL->setPixmap(icon);
 
